@@ -33,8 +33,11 @@
 //! ## Utilities
 //!
 //! The crate provides utilities for launching local Ethereum testnets by using `ganache-cli`
-//! via the `GanacheBuilder` struct. In addition, you're able to compile contracts on the
-//! filesystem by providing a glob to their path, using the `Solc` struct.
+//! via the `GanacheBuilder` struct.
+//!
+//! # Features
+//!
+//! * - ["eip712"] | Provides Eip712 trait for EIP-712 encoding of typed data for derived structs
 //!
 //! # ABI Encoding and Decoding
 //!
@@ -48,6 +51,9 @@ pub mod abi;
 /// Various utilities
 pub mod utils;
 
+#[cfg(feature = "macros")]
+pub mod macros;
+
 // re-export rand to avoid potential confusion when there's rand version mismatches
 pub use rand;
 
