@@ -1,4 +1,7 @@
-use super::{eip1559::Eip1559TransactionRequest, eip2930::Eip2930TransactionRequest};
+use super::{
+    eip1559::Eip1559TransactionRequest,
+    eip2930::{AccessList, Eip2930TransactionRequest},
+};
 use crate::{
     types::{Address, Bytes, NameOrAddress, Signature, TransactionRequest, H256, U256, U64},
     utils::keccak256,
@@ -16,7 +19,6 @@ use serde::{Deserialize, Serialize};
 /// the `legacy` crate feature. This will disable the `type` flag in the
 /// serialized transaction, and cause contract calls and other common actions
 /// to default to using the legacy transaction type.
-///
 #[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
 #[cfg_attr(not(feature = "legacy"), serde(tag = "type"))]
 #[cfg_attr(feature = "legacy", serde(untagged))]
@@ -119,6 +121,21 @@ impl TypedTransaction {
         };
     }
 
+    pub fn gas_price(&self) -> Option<U256> {
+        match self {
+            Legacy(inner) => inner.gas_price,
+            Eip2930(inner) => inner.tx.gas_price,
+            Eip1559(inner) => {
+                match (inner.max_fee_per_gas, inner.max_priority_fee_per_gas) {
+                    (Some(basefee), Some(prio_fee)) => Some(basefee + prio_fee),
+                    // this also covers the None, None case
+                    (None, prio_fee) => prio_fee,
+                    (basefee, None) => basefee,
+                }
+            }
+        }
+    }
+
     pub fn set_gas_price<T: Into<U256>>(&mut self, gas_price: T) {
         let gas_price = gas_price.into();
         match self {
@@ -139,6 +156,22 @@ impl TypedTransaction {
         }
     }
 
+    pub fn access_list(&self) -> Option<&AccessList> {
+        match self {
+            Legacy(_) => None,
+            Eip2930(inner) => Some(&inner.access_list),
+            Eip1559(inner) => Some(&inner.access_list),
+        }
+    }
+
+    pub fn set_access_list(&mut self, access_list: AccessList) {
+        match self {
+            Legacy(_) => {}
+            Eip2930(inner) => inner.access_list = access_list,
+            Eip1559(inner) => inner.access_list = access_list,
+        };
+    }
+
     pub fn set_data(&mut self, data: Bytes) {
         match self {
             Legacy(inner) => inner.data = Some(data),
@@ -218,9 +251,7 @@ mod tests {
 
     #[test]
     fn serde_legacy_tx() {
-        let tx = TransactionRequest::new()
-            .to(Address::zero())
-            .value(U256::from(100));
+        let tx = TransactionRequest::new().to(Address::zero()).value(U256::from(100));
         let tx: TypedTransaction = tx.into();
         let serialized = serde_json::to_string(&tx).unwrap();
 
