@@ -5,6 +5,9 @@ pub mod eip1559;
 pub mod eip2718;
 pub mod eip2930;
 
+#[cfg(feature = "eip712")]
+pub mod eip712;
+
 pub(crate) const BASE_NUM_TX_FIELDS: usize = 9;
 
 // Number of tx fields before signing
