@@ -110,11 +110,7 @@ impl Geth {
         let mut cmd = Command::new(GETH);
         // geth uses stderr for its logs
         cmd.stderr(std::process::Stdio::piped());
-        let port = if let Some(port) = self.port {
-            port
-        } else {
-            unused_port()
-        };
+        let port = if let Some(port) = self.port { port } else { unused_port() };
 
         // Open the HTTP API
         cmd.arg("--http");
@@ -138,9 +134,7 @@ impl Geth {
 
         let mut child = cmd.spawn().expect("couldnt start geth");
 
-        let stdout = child
-            .stderr
-            .expect("Unable to get stderr for geth child process");
+        let stdout = child.stderr.expect("Unable to get stderr for geth child process");
 
         let start = Instant::now();
         let mut reader = BufReader::new(stdout);
@@ -151,22 +145,16 @@ impl Geth {
             }
 
             let mut line = String::new();
-            reader
-                .read_line(&mut line)
-                .expect("Failed to read line from geth process");
+            reader.read_line(&mut line).expect("Failed to read line from geth process");
 
             // geth 1.9.23 uses "server started" while 1.9.18 uses "endpoint opened"
             if line.contains("HTTP endpoint opened") || line.contains("HTTP server started") {
-                break;
+                break
             }
         }
 
         child.stderr = Some(reader.into_inner());
 
-        GethInstance {
-            pid: child,
-            port,
-            ipc: self.ipc_path,
-        }
+        GethInstance { pid: child, port, ipc: self.ipc_path }
     }
 }
