@@ -10,20 +10,6 @@ mod geth;
 #[cfg(not(target_arch = "wasm32"))]
 pub use geth::{Geth, GethInstance};
 
-/// Solidity compiler bindings
-#[cfg(not(target_arch = "wasm32"))]
-mod solc;
-
-#[cfg(not(target_arch = "wasm32"))]
-pub use solc::{CompiledContract, Solc};
-
-#[cfg(not(target_arch = "wasm32"))]
-#[cfg(feature = "setup")]
-mod setup;
-#[cfg(not(target_arch = "wasm32"))]
-#[cfg(feature = "setup")]
-pub use setup::*;
-
 mod hash;
 pub use hash::{hash_message, id, keccak256, serialize};
 
@@ -33,6 +19,9 @@ pub use units::Units;
 /// Re-export RLP
 pub use rlp;
 
+/// Re-export hex
+pub use hex;
+
 use crate::types::{Address, Bytes, U256};
 use k256::{ecdsa::SigningKey, EncodedPoint as K256PublicKey};
 use std::ops::Neg;
@@ -203,13 +192,9 @@ pub fn get_create2_address_from_hash(
     salt: impl Into<Bytes>,
     init_code_hash: impl Into<Bytes>,
 ) -> Address {
-    let bytes = [
-        &[0xff],
-        from.into().as_bytes(),
-        salt.into().as_ref(),
-        init_code_hash.into().as_ref(),
-    ]
-    .concat();
+    let bytes =
+        [&[0xff], from.into().as_bytes(), salt.into().as_ref(), init_code_hash.into().as_ref()]
+            .concat();
 
     let hash = keccak256(&bytes);
 
@@ -241,17 +226,14 @@ pub fn to_checksum(addr: &Address, chain_id: Option<u8>) -> String {
     let addr_hex = hex::encode(addr.as_bytes());
     let addr_hex = addr_hex.as_bytes();
 
-    addr_hex
-        .iter()
-        .zip(hash)
-        .fold("0x".to_owned(), |mut encoded, (addr, hash)| {
-            encoded.push(if *hash >= 56 {
-                addr.to_ascii_uppercase() as char
-            } else {
-                addr.to_ascii_lowercase() as char
-            });
-            encoded
-        })
+    addr_hex.iter().zip(hash).fold("0x".to_owned(), |mut encoded, (addr, hash)| {
+        encoded.push(if *hash >= 56 {
+            addr.to_ascii_uppercase() as char
+        } else {
+            addr.to_ascii_lowercase() as char
+        });
+        encoded
+    })
 }
 
 /// Returns a bytes32 string representation of text. If the length of text exceeds 32 bytes,
@@ -259,7 +241,7 @@ pub fn to_checksum(addr: &Address, chain_id: Option<u8>) -> String {
 pub fn format_bytes32_string(text: &str) -> Result<[u8; 32], FormatBytes32StringError> {
     let str_bytes: &[u8] = text.as_bytes();
     if str_bytes.len() > 32 {
-        return Err(FormatBytes32StringError::TextTooLong);
+        return Err(FormatBytes32StringError::TextTooLong)
     }
 
     let mut bytes32: [u8; 32] = [0u8; 32];
@@ -299,16 +281,13 @@ pub fn eip1559_default_estimator(base_fee_per_gas: U256, rewards: Vec<Vec<U256>>
 }
 
 fn estimate_priority_fee(rewards: Vec<Vec<U256>>) -> U256 {
-    let mut rewards: Vec<U256> = rewards
-        .iter()
-        .map(|r| r[0])
-        .filter(|r| *r > U256::zero())
-        .collect();
+    let mut rewards: Vec<U256> =
+        rewards.iter().map(|r| r[0]).filter(|r| *r > U256::zero()).collect();
     if rewards.is_empty() {
-        return U256::zero();
+        return U256::zero()
     }
     if rewards.len() == 1 {
-        return rewards[0];
+        return rewards[0]
     }
     // Sort the rewards as we will eventually take the median.
     rewards.sort();
@@ -333,15 +312,12 @@ fn estimate_priority_fee(rewards: Vec<Vec<U256>>) -> U256 {
 
     // Fetch the max of the percentage change, and that element's index.
     let max_change = percentage_change.iter().max().unwrap();
-    let max_change_index = percentage_change
-        .iter()
-        .position(|&c| c == *max_change)
-        .unwrap();
+    let max_change_index = percentage_change.iter().position(|&c| c == *max_change).unwrap();
 
     // If we encountered a big change in fees at a certain position, then consider only
     // the values >= it.
-    let values = if *max_change >= EIP1559_FEE_ESTIMATION_THRESHOLD_MAX_CHANGE
-        && (max_change_index >= (rewards.len() / 2))
+    let values = if *max_change >= EIP1559_FEE_ESTIMATION_THRESHOLD_MAX_CHANGE &&
+        (max_change_index >= (rewards.len() / 2))
     {
         rewards[max_change_index..].to_vec()
     } else {
@@ -373,9 +349,8 @@ pub(crate) fn unused_port() -> u16 {
     let listener = std::net::TcpListener::bind("127.0.0.1:0")
         .expect("Failed to create TCP listener to find unused port");
 
-    let local_addr = listener
-        .local_addr()
-        .expect("Failed to read TCP listener local_addr to find unused port");
+    let local_addr =
+        listener.local_addr().expect("Failed to read TCP listener local_addr to find unused port");
     local_addr.port()
 }
 
@@ -404,16 +379,10 @@ mod tests {
         assert_eq!(gwei.as_u64(), 15e8 as u64);
 
         let eth_dec_float = parse_units(1.39563324, "ether").unwrap();
-        assert_eq!(
-            eth_dec_float,
-            U256::from_dec_str("1395633240000000000").unwrap()
-        );
+        assert_eq!(eth_dec_float, U256::from_dec_str("1395633240000000000").unwrap());
 
         let eth_dec_string = parse_units("1.39563324", "ether").unwrap();
-        assert_eq!(
-            eth_dec_string,
-            U256::from_dec_str("1395633240000000000").unwrap()
-        );
+        assert_eq!(eth_dec_string, U256::from_dec_str("1395633240000000000").unwrap());
 
         let eth = parse_units(1, "ether").unwrap();
         assert_eq!(eth, WEI_IN_ETHER);
@@ -510,9 +479,7 @@ mod tests {
     #[test]
     fn contract_address() {
         // http://ethereum.stackexchange.com/questions/760/how-is-the-address-of-an-ethereum-contract-computed
-        let from = "6ac7ea33f8831ea9dcc53393aaa88b25a785dbf0"
-            .parse::<Address>()
-            .unwrap();
+        let from = "6ac7ea33f8831ea9dcc53393aaa88b25a785dbf0".parse::<Address>().unwrap();
         for (nonce, expected) in [
             "cd234a471b72ba2f1ccf0a70fcaba648a5eecd8d",
             "343c43a37d37dff08ae8c4a11544c718abb4fcf8",
@@ -590,14 +557,8 @@ mod tests {
     #[test]
     fn bytes32_string_parsing() {
         let text_bytes_list = vec![
-            (
-                "",
-                hex!("0000000000000000000000000000000000000000000000000000000000000000"),
-            ),
-            (
-                "A",
-                hex!("4100000000000000000000000000000000000000000000000000000000000000"),
-            ),
+            ("", hex!("0000000000000000000000000000000000000000000000000000000000000000")),
+            ("A", hex!("4100000000000000000000000000000000000000000000000000000000000000")),
             (
                 "ABCDEFGHIJKLMNOPQRSTUVWXYZ012345",
                 hex!("4142434445464748494a4b4c4d4e4f505152535455565758595a303132333435"),
@@ -616,14 +577,8 @@ mod tests {
     #[test]
     fn bytes32_string_formatting() {
         let text_bytes_list = vec![
-            (
-                "",
-                hex!("0000000000000000000000000000000000000000000000000000000000000000"),
-            ),
-            (
-                "A",
-                hex!("4100000000000000000000000000000000000000000000000000000000000000"),
-            ),
+            ("", hex!("0000000000000000000000000000000000000000000000000000000000000000")),
+            ("A", hex!("4100000000000000000000000000000000000000000000000000000000000000")),
             (
                 "ABCDEFGHIJKLMNOPQRSTUVWXYZ012345",
                 hex!("4142434445464748494a4b4c4d4e4f505152535455565758595a303132333435"),
@@ -654,10 +609,7 @@ mod tests {
         let base_fee_per_gas = U256::from(EIP1559_FEE_ESTIMATION_PRIORITY_FEE_TRIGGER) - 1;
         let rewards: Vec<Vec<U256>> = vec![vec![]];
         let (base_fee, priority_fee) = eip1559_default_estimator(base_fee_per_gas, rewards);
-        assert_eq!(
-            priority_fee,
-            U256::from(EIP1559_FEE_ESTIMATION_DEFAULT_PRIORITY_FEE)
-        );
+        assert_eq!(priority_fee, U256::from(EIP1559_FEE_ESTIMATION_DEFAULT_PRIORITY_FEE));
         assert_eq!(base_fee, base_fee_surged(base_fee_per_gas));
 
         // If the base fee is above the triggering base fee, we calculate the priority fee using
